#include <stdio.h>
#include <gmp.h>
#include <mpfr.h>

/*
 * To compile:
 * gcc -O3 test_mpfr2.c -o test_mpfr2 -lmpfr
 *
 */

int main (void)
{
  int i;
  mpfr_t xa, xb;
  int exact;
  volatile double a, b;

  mpfr_set_default_prec (53);
  // min subnormal 2^−1074, i.e. 0.1·2−1073
  mpfr_set_emin (-1073);
  mpfr_set_emax (1024);

  mpfr_init (xa);
  mpfr_init (xb);

  a = 0x1.1235P-1021;
  b = 34.3;
  
  mpfr_set_d (xa, 0x1.1235P-1021, MPFR_RNDN);
  mpfr_set_d (xb, 34.3, MPFR_RNDN);
  
  a /= b;

  // Ternary value: (=0) exact, (<0) lower than exact, (>0) greater than exact
  exact = mpfr_div (xa, xa, xb, MPFR_RNDN);
  exact = mpfr_subnormalize (xa, i, MPFR_RNDN); //  Emin + PREC(x) − 1 = -1022

  printf("%.20e\n", a);
  mpfr_out_str (stdout, 10, 0, xa, MPFR_RNDD);
  putchar ('\n');

  mpfr_clear (xa);
  mpfr_clear (xb);

  return 0;
}
